import { KMS } from 'aws-sdk';

const kms = new KMS();
const isBase64 = /^([A-Za-z0-9+/]{4})*([A-Za-z0-9+/]{4}|[A-Za-z0-9+/]{3}=|[A-Za-z0-9+/]{2}==)$/;
const dictionary = new Map();
async function decrypt(ciphertext) {
    const result = await kms
        .decrypt({ CiphertextBlob: Buffer.from(ciphertext, 'base64') })
        .promise();
    const plaintext = result.Plaintext ? result.Plaintext.toString() : ciphertext;
    return dictionary.set(ciphertext, plaintext) && plaintext;
}
var kmsDecrypt = (ciphertext) => ciphertext.length === 0 ||
    process.env.DISABLE_AWS_KMS_THINGY ||
    !isBase64.test(ciphertext)
    ? String(ciphertext)
    :
        dictionary.get(ciphertext) ||
            decrypt(ciphertext);

const kms$1 = new KMS();
const dictionary$1 = new Map();
async function encrypt({ plaintext, keyId, }) {
    const result = await kms$1
        .encrypt({ KeyId: keyId, Plaintext: plaintext })
        .promise();
    const ciphertext = result.CiphertextBlob
        ? result.CiphertextBlob.toString('base64')
        : plaintext;
    return dictionary$1.set(plaintext, ciphertext) && ciphertext;
}
var kmsEncrypt = ({ plaintext, keyId, }) => process.env.DISABLE_AWS_KMS_THINGY
    ? String(plaintext)
    :
        dictionary$1.get(keyId + plaintext) ||
            encrypt({ plaintext, keyId });

async function encrypt$1(parameters) {
    return 'plaintext' in parameters
        ? kmsEncrypt(parameters)
        : Promise.all(parameters.map(kmsEncrypt));
}
async function decrypt$1(ciphertext) {
    return typeof ciphertext === 'undefined'
        ? undefined
        : typeof ciphertext === 'string'
            ? kmsDecrypt(ciphertext)
            : Promise.all(ciphertext.map(kmsDecrypt));
}

export { encrypt$1 as encrypt, decrypt$1 as decrypt };
